@@ -36,8 +36,8 @@ class PyutLink(PyutObject):
                  cardSrc:      str = "",
                  cardDest:     str = "",
                  bidir:        bool = False,
-                 source:       'PyutClass' = None,
-                 destination:  Union['PyutClass', 'PyutNote'] = None):
+                 source:       Optional['PyutClass']                    = None,
+                 destination:  Optional[Union['PyutClass', 'PyutNote']] = None):
         """
 
         Args:
